
/*
 *  HTGeodesic.java
 *  www.bouthier.net
 *
 *  The MIT License :
 *  -----------------
 *  Copyright (c) 2001 Christophe Bouthier
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 */
// Cdigo alterado por Silvio Evangelista

//package hypertree;
import java.awt.*;
//Graphics;
//import java.awt.Font;

import java.awt.Color;
//import java.awt.Insets;
import java.util.*;

/**
 * The HTDraw class implements the drawing model for the HTView.
 *
 * @author     silvio
 * @created    15 de Setembro de 2008
 */
class HTDraw {

	private final static int NBR_FRAMES = 10;
	// number of intermediates animation frames
	private HTModel model = null;
	// the tree model
	private HTView view = null;
	// the view using this drawing model
	private HTDrawNode drawRoot = null;
	// the root of the drawing tree
	private HTCoordS sOrigin = null;
	// origin of the screen plane
	private HTCoordS sMax = null;
	// max point in the screen plane
	private double[] ray = null;
	private boolean fastMode = false;
	// fast mode
	private static int fh, fa, fl;
	private static int charWidth;
	private static FontMetrics fm;
	// Bruno - era private static
	/**
	 *  Description of the Field
	 */
	public Font mainFont;
	private static boolean first = false;


	/*
	 *  int     hpx = 25;
	 *  int     hpy = 50;
	 *  int     hw  = 10;
	 *  int     hl  = 15;
	 *  int     hs  = 30;
	 */
	/*
	 *  --- Constructor ---
	 */
	/**
	 * Constructor.
	 *
	 * @param  model  the tree model to draw
	 * @param  view   the view using this drawing model
	 */
	HTDraw(HTModel model, HTView view) {

		this.view = view;
		this.model = model;

		HTModelNode root = model.getRoot();
		sOrigin = new HTCoordS();
		sMax = new HTCoordS();

		ray = new double[4];
		ray[0] = model.getLength();

		for (int i = 1; i < ray.length; i++) {
			ray[i] = (ray[0] + ray[i - 1]) / (1 + (ray[0] * ray[i - 1]));
		}

		if (root.isLeaf()) {
			drawRoot = new HTDrawNode(null, root, this);
		} else {
			drawRoot = new HTDrawNodeComposite(null, (HTModelNodeComposite) root, this);
		}

	}


	/*
	 *  --- Screen coordinates ---
	 */
	/**
	 * Refresh the screen coordinates of the drawing tree.
	 */
	void refreshScreenCoordinates() {
		Insets insets = view.getInsets();
		sMax.x = (view.getSize().width - insets.left - insets.right) / 2;
		sMax.y = (view.getSize().height - insets.top - insets.bottom) / 2;
		sOrigin.x = sMax.x + insets.left;
		sOrigin.y = sMax.y + insets.top;
		drawRoot.refreshScreenCoordinates(sOrigin, sMax);
	}


	/**
	 * Returns the origin of the screen plane.
	 * WARNING : this is not a copy but the original object.
	 *
	 * @return    the origin of the screen plane
	 */
	HTCoordS getSOrigin() {
		return sOrigin;
	}


	/**
	 * Return the point representing the up right corner
	 * of the screen plane, thus giving x and y maxima.
	 * WARNING : this is not a copy but the original object.
	 *
	 * @return    the max point
	 */
	HTCoordS getSMax() {
		return sMax;
	}


	/*
	 *  --- Drawing ---
	 */
	/**
	 * Draws the branches of the hyperbolic tree.
	 *
	 * @param  g  the graphic context
	 */
	void drawBranches(Graphics g) {
		drawRoot.drawBranches(g);
	}


	/**
	 * Draws the nodes of the hyperbolic tree.
	 *
	 * @param  g  the graphic context
	 */
	void drawNodes(Graphics g) {
		// if (!first) {
		mainFont = new Font(this.view.getFontNode(), Font.PLAIN, this.view.getFontSizeNode());

		g.setFont(mainFont);
		fm = g.getFontMetrics();
		fh = fm.getHeight();
		fa = fm.getAscent();
		fl = fm.getLeading();

		String name = "a";
		char[] nameC = name.toCharArray();
		charWidth = fm.charsWidth(nameC, 0, 1);
		first = true;
		//  }

		g.setColor(new Color(Color.decode(getLinkColor()).getRGB()));
		g.drawString("Busca:", 15, 14);

		if (view.nGraphLines() > 0) {
			if (view.getViewLineGraph()) {
				g.setColor(new Color(Color.decode(getLinkColor()).getRGB()));
				g.fillRect(15, 50, 12, 12);
			} else {
				g.setColor(new Color(Color.decode(getBackColor()).getRGB()));
				g.fillRect(15, 50, 12, 12);
				g.setColor(new Color(Color.decode(getLinkColor()).getRGB()));
				g.drawRect(15, 50, 12, 12);
			}
			g.drawString("Mostrar linhas de grafo", 32, 62);


			int ng_x = 15;
			int ng_y = 66;

			for (int nlg=0; nlg < view.graphNames.size(); nlg++) {
				if (view.getGraphShowI(nlg)) {
					g.setColor(new Color(Color.decode(view.getGraphColorI(nlg)).getRGB()));//getLinkColor()).getRGB()));
					g.fillRect(ng_x, ng_y, 12, 12);
				} else {
					g.setColor(new Color(Color.decode(getBackColor()).getRGB()));
					g.fillRect(ng_x, ng_y, 12, 12);
					g.setColor(new Color(Color.decode(getLinkColor()).getRGB()));
					g.drawRect(ng_x, ng_y, 12, 12);
				}
				g.drawString(view.getGraphNameI(nlg), 32, ng_y + 12);

				ng_y = ng_y + 16;
			}
		}

		//g.drawString("Mestrado Profissional em Agroenergia", 15, view.getHeight()-55);
		//g.drawString("Embrapa Informtica Agropecuria", 15, view.getHeight()-40);
		//g.drawString("Risco, Planejamento e Preciso no Agronegcio", 15, view.getHeight()-25);
		//g.drawString("Professor: Eduardo Delgado Assad", 15, view.getHeight()-10);
		g.drawString("Embrapa Informtica Agropecuria", 15, view.getHeight()-10);


		/*
		 *  drawRoot.drawNodes0(g);
		 *  drawRoot.drawNodes(g);
		 */
		/*
		 *  Bruno
		 *  Indica se os ns filhos devem mostrar as figuras
		 */
		String res = drawRoot.getNodeClientData();

		drawRoot.drawLinesGraph(g);
		// 12/08/2009

		if (res.charAt(0) == '1') {
			// Mostra as figuras
			drawRoot.drawNodes0(g, true);
			drawRoot.drawNodes(g, true);
		} else {
			drawRoot.drawNodes0(g, false);
			drawRoot.drawNodes(g, false);
			// Esconde as figuras
		}
		// Fim bruno

	}


	/**
	 *  Description of the Method
	 *
	 * @param  zs  Description of the Parameter
	 * @return     Description of the Return Value
	 */
	int verifyGraphLine(HTCoordS zs) {
		// g.drawRect(15, 50, 12, 12);

		int r = verifyGraphNamesClick(zs);

		if (r==1)
			return 2;

		int px = zs.x;
		int py = zs.y;
		if (view.nGraphLines() > 0) {
			if ((px >= (15)) && (px <= (15 + 12)) && (py >= 50) && (py <= 50 + 12)) {
				return 1;
			} else {
				return 0;
			}
		} else {
			return 0;
		}

	}

	int verifyGraphNamesClick(HTCoordS zs) {

		int px = zs.x;
		int py = zs.y;

		if (view.nGraphLines() > 0) {
			int ng_x = 15;
			int ng_y = 66;

			for (int nlg=0; nlg < view.graphNames.size(); nlg++) {
				if ((px >= (ng_x)) && (px <= (ng_x + 12)) && (py >= ng_y) && (py <= ng_y + 12)) {
					if (view.getGraphShowI(nlg))
						view.setGraphShowI(nlg,false);
					else
						view.setGraphShowI(nlg, true);
					return (1);
				}
				ng_y = ng_y + 16;
			}
		}
		return 0;

	}

	/**
	 *  Description of the Method
	 *
	 * @param  zs  Description of the Parameter
	 * @return     Description of the Return Value
	 */
	int verifyHomeClick(HTCoordS zs) {

		int px = zs.x;
		int py = zs.y;
		Rectangle rect = view.getHomeRect();

		if (rect == null) {
			return 0;
		}
		if ((px >= (rect.x)) && (px <= (rect.x + rect.width)) && (py >= rect.y) && (py <= rect.y + rect.height)) {
			translateToRootOrigin();
			return 0;
		}

		if (view.getCenterNode() != null) {
			if ((px >= (rect.x + rect.width)) && (px <= (rect.x + rect.width + rect.width)) && (py >= rect.y) && (py <= rect.y + rect.height)) {

				HTDrawNode result = findNode(view.getCenterNode().toLowerCase());
				if (result != null) {
					translateToOrigin(result);
				}
				return 0;
			}
			//if (  (px >= (view.getSize().width-rect.width*2+rect.x)) && ( px<= (view.getSize().width-rect.width*2+rect.x+rect.width)) && (py >= 10) && (py <= 10+rect.height)) {
		}
		if ((px >= (rect.width + rect.x * 3)) && (px <= ((rect.width + rect.x * 3) + rect.width)) && (py >= rect.y) && (py <= rect.y + rect.height)) {
			return 1;
		}

		return 0;
	}


	/**
	 * Draws the Hint of the selectioned node.
	 *
	 * @param  g  the graphic context
	 */
	void drawHint(Graphics g) {
		drawRoot.drawHint(g);
	}


	/*
	 *  --- Translation ---
	 */
	/**
	 * Translates the hyperbolic tree by the given vector.
	 *
	 * @param  zs  Description of the Parameter
	 * @param  ze  Description of the Parameter
	 */
	void translate(HTCoordE zs, HTCoordE ze) {
		HTCoordE zo = new HTCoordE(drawRoot.getOldCoordinates());
		zo.x = -zo.x;
		zo.y = -zo.y;
		HTCoordE zs2 = new HTCoordE(zs);
		zs2.translate(zo);

		HTCoordE t = new HTCoordE();
		double de = ze.d2();
		double ds = zs2.d2();
		double dd = 1.0 - de * ds;
		t.x = (ze.x * (1.0 - ds) - zs2.x * (1.0 - de)) / dd;
		t.y = (ze.y * (1.0 - ds) - zs2.y * (1.0 - de)) / dd;

		if (t.isValid()) {
			HTTransformation to = new HTTransformation();
			to.composition(zo, t);

			drawRoot.transform(to);
			view.repaint();
		}
	}


	/**
	 * Signal that the translation ended.
	 */
	void endTranslation() {
		drawRoot.endTranslation();
	}


	/**
	 * Translate the hyperbolic tree so that the given node
	 * is put at the origin of the hyperbolic tree.
	 *
	 * @param  node  the given HTDrawNode
	 */
	void translateToOrigin(HTDrawNode node) {
		view.stopMouseListening();
		AnimThread t = new AnimThread(node);
		t.start();
	}


	/**
	 *  Description of the Method
	 */
	void translateToRootOrigin() {
		view.stopMouseListening();
		AnimThread t = new AnimThread(drawRoot);
		t.start();
	}


	/**
	 * Restores the hyperbolic tree to its origin.
	 */
	void restore() {
		drawRoot.restore();
		view.repaint();
	}


	/**
	 * reDraw the hyperbolic tree.
	 * This functions is called when the user ask for a hint
	 */
	void reDraw() {
		//view.setHasHint(true);
		view.repaint();
		//view.setHasHint(false);
	}


	/**
	 * Get width of the panel.
	 *
	 * @return    The widthPanel value
	 */
	int getWidthPanel() {
		return view.getSize().width;
		// getWidth();
	}


	/**
	 * Get length of the Panel
	 *
	 * @return    The heightPanel value
	 */
	int getHeightPanel() {
		return view.getSize().height;
		// getHeight();
	}


	/**
	 * Set that there is one Hint to be showed
	 *
	 * @param  v  The new hint value
	 */
	void setHint(boolean v) {
		view.setHasHint(v);
	}


	/**
	 *  Gets the helpFile attribute of the HTDraw object
	 *
	 * @return    The helpFile value
	 */
	String getHelpFile() {
		return view.getHelpFile();
	}


	/**
	 *  Gets the urlAdr attribute of the HTDraw object
	 *
	 * @return    The urlAdr value
	 */
	String getUrlAdr() {
		return view.getUrlAdr();
	}


	// 14/11/2005
	/**
	 * get the representation type of search:
	 *   line: line thicher
	 *   blende: blende mode. This type use transparency color.
	 *
	 * @return    The searchType value
	 */
	boolean getSearchType() {
		return view.getSearchType();
	}


	/**
	 * Indicates if the hypertree space is in search mode.
	 *
	 * @return    The isSearch value
	 */
	boolean getIsSearch() {
		return view.getIsSearch();
	}


	// *************
	/**
	 *  Gets the openWindow attribute of the HTDraw object
	 *
	 * @return    The openWindow value
	 */
	String getOpenWindow() {
		return view.getOpenWindow();
	}


	/**
	 * Sets the fast mode, where nodes are no more drawed.
	 *
	 * @param  mode  setting on or off.
	 */
	void fastMode(boolean mode) {
		if (mode != fastMode) {
			fastMode = mode;
			drawRoot.fastMode(mode);
			if (mode == false) {
				view.repaint();
			}
		}
	}


	// 13/09/2004
	/**
	 *  Description of the Method
	 *
	 * @param  zs  Description of the Parameter
	 * @return     Description of the Return Value
	 */
	int verifyFolder(HTCoordS zs) {
		return drawRoot.verifyFolder(zs);
	}


	/*
	 *  --- Node searching ---
	 */
	/**
	 * Returns the node (if any) whose screen coordinates' zone
	 * contains thoses given in parameters.
	 *
	 * @param  zs  the given screen coordinate
	 * @return     the searched HTDrawNode if found;
	 *              <CODE>null</CODE> otherwise
	 */
	HTDrawNode findNode(HTCoordS zs) {
		return drawRoot.findNode(zs);
	}


	/**
	 *  Gets the clickOnImage attribute of the HTDraw object
	 *
	 * @return    The clickOnImage value
	 */
	boolean getClickOnImage() {
		return drawRoot.getClickOnImage();
	}


	/**
	 * Searching a node in HTDrawNodeCompisite
	 *
	 * @param  idNode  String
	 * @return         Description of the Return Value
	 */
	HTDrawNode findNode(String idNode) {
		return (drawRoot.findNode(idNode));
	}


	/**
	 * Returns the hint color armazened in view class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getHintColor() {
		return view.getHintColor();
	}


	/**
	 *  Gets the backColor attribute of the HTDraw object
	 *
	 * @return    The backColor value
	 */
	String getBackColor() {
		return view.getBackColor();
	}


	// 17/11/2005
	/**
	 *  Gets the backRed attribute of the HTDraw object
	 *
	 * @return    The backRed value
	 */
	int getBackRed() {

		return view.getBackRed();
	}


	/**
	 *  Gets the backGreen attribute of the HTDraw object
	 *
	 * @return    The backGreen value
	 */
	int getBackGreen() {

		return view.getBackGreen();
	}


	/**
	 *  Gets the backBlue attribute of the HTDraw object
	 *
	 * @return    The backBlue value
	 */
	int getBackBlue() {

		return view.getBackBlue();
	}


// ******
	/**
	 *  Gets the hasFolder attribute of the HTDraw object
	 *
	 * @return    The hasFolder value
	 */
	boolean getHasFolder() {
		return view.getHasFolder();
	}


	/**
	 * Returns the type box of leaf node
	 * contains thoses given in parameters.
	 *
	 * @return    Type of leaf node
	 */
	String getLeafNode() {
		return view.getLeafNode();
	}


	/**
	 *  Gets the parentNode attribute of the HTDraw object
	 *
	 * @return    The parentNode value
	 */
	String getParentNode() {
		return view.getParentNode();
	}


	/**
	 * Returns the name of the font via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getFontNode() {
		return view.getFontNode();
	}


	/**
	 * Returns the size of the font, via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	int getFontSizeNode() {
		return view.getFontSizeNode();
	}


	/**
	 * Returns the border type of retangule armazende in view class
	 * contains thoses given in parameters.
	 *
	 * @return    String
	 */
	String getBorderType() {
		return view.getBorderType();
	}


	/**
	 * Returns the text of search box, if has one.
	 *
	 * @return    String
	 */
	String getSearchWord() {
		return (view.getSearchWord());
	}


	/**
	 * Returns the link color armazened in view class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getLinkColor() {
		return view.getLinkColor();
	}


	/**
	 * Returns the search color armazened in view class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getSearchColor() {
		return view.getSearchColor();
	}


	/*
	 *  String getNameArest() {
	 *  return (view.getNameArest());
	 *  }
	 */
	/**
	 *  Gets the charWidth attribute of the HTDraw object
	 *
	 * @return    The charWidth value
	 */
	int getCharWidth() {
		return (charWidth);
	}


	/**
	 *  Gets the charHeight attribute of the HTDraw object
	 *
	 * @return    The charHeight value
	 */
	int getCharHeight() {
		return (fh);
	}


	/**
	 *  Gets the ascent attribute of the HTDraw object
	 *
	 * @return    The ascent value
	 */
	int getAscent() {
		return (fa);
	}


	/**
	 *  Gets the leading attribute of the HTDraw object
	 *
	 * @return    The leading value
	 */
	int getLeading() {
		return (fl);
	}


	/**
	 *  Gets the stringWidth attribute of the HTDraw object
	 *
	 * @param  nameC  Description of the Parameter
	 * @param  init   Description of the Parameter
	 * @param  end    Description of the Parameter
	 * @return        The stringWidth value
	 */
	int getStringWidth(char[] nameC, int init, int end) {
		if (fm == null) {
			return 0;
		}
		if (new String(nameC) == null) {
			return 0;
		} else {
			return (fm.charsWidth(nameC, init, end));
		}
	}


	/**
	 *  Gets the stringWidth attribute of the HTDraw object
	 *
	 * @param  nameC  Description of the Parameter
	 * @return        The stringWidth value
	 */
	int getStringWidth(String nameC) {
		if (fm == null) {
			return 0;
		}
		if (nameC == null) {
			return 0;
		} else {
			return (fm.stringWidth(nameC));
		}
	}


	/*
	 *  --- Inner animation thread ---
	 */
	/**
	 * The AnimThread class implements the thread that do the animation
	 * when clicking on a node.
	 *
	 * @author     silvio
	 * @created    15 de Setembro de 2008
	 */
	class AnimThread
			 extends Thread {

		private HTDrawNode node = null;
		// node to put at the origin
		private Runnable tTask = null;

		// translation task


		/**
		 * Constructor.
		 *
		 * @param  node  the node to put at the origin
		 */
		AnimThread(HTDrawNode node) {
			this.node = node;
		}


		/**
		 * Do the animation.
		 */
		public void run() {
			HTCoordE zn = node.getOldCoordinates();
			HTCoordE zf = new HTCoordE();

			int frames = NBR_FRAMES;
			int nodes = model.getNumberOfNodes();

			double d = zn.d();
			for (int i = 0; i < ray.length; i++) {
				if (d > ray[i]) {
					frames += NBR_FRAMES / 2;
				}
			}

			double factorX = zn.x / frames;
			double factorY = zn.y / frames;

			for (int i = 1; i < frames; i++) {
				zf.x = zn.x - (i * factorX);
				zf.y = zn.y - (i * factorY);
				tTask = new TranslateThread(zn, zf);
				try {

					//SwingUtilities.invokeAndWait(tTask);
					sleep(10);
					tTask.run();
				} catch (Exception e) {
					e.printStackTrace();
				}
			}

			zf.x = 0.0;
			zf.y = 0.0;
			tTask = new LastTranslateThread(zn, zf);
			try {
				//SwingUtilities.invokeAndWait(tTask);
				sleep(25);
				tTask.run();
			} catch (Exception e) {
				e.printStackTrace();
			}
		}


		/*
		 *  --- Inner's inner ---
		 */
		/**
		 *  Description of the Class
		 *
		 * @author     silvio
		 * @created    15 de Setembro de 2008
		 */
		class TranslateThread
				 implements Runnable {

			HTCoordE zStart = null;
			HTCoordE zEnd = null;


			/**
			 *Constructor for the TranslateThread object
			 *
			 * @param  z1  Description of the Parameter
			 * @param  z2  Description of the Parameter
			 */
			TranslateThread(HTCoordE z1, HTCoordE z2) {
				zStart = z1;
				zEnd = z2;
			}


			/**
			 *  Main processing method for the TranslateThread object
			 */
			public void run() {
				translate(zStart, zEnd);
				view.repaint();
			}
		}


		/**
		 *  Description of the Class
		 *
		 * @author     silvio
		 * @created    15 de Setembro de 2008
		 */
		class LastTranslateThread
				 implements Runnable {

			HTCoordE zStart = null;
			HTCoordE zEnd = null;


			/**
			 *Constructor for the LastTranslateThread object
			 *
			 * @param  z1  Description of the Parameter
			 * @param  z2  Description of the Parameter
			 */
			LastTranslateThread(HTCoordE z1, HTCoordE z2) {
				zStart = z1;
				zEnd = z2;
			}


			/**
			 *  Main processing method for the LastTranslateThread object
			 */
			public void run() {
				translate(zStart, zEnd);
				endTranslation();
				view.repaint();
				view.startMouseListening();
			}
		}
	}


	/**
	 *  Gets the numAnds attribute of the HTDraw object
	 *
	 * @return    The numAnds value
	 */
	int getNumAnds() {
		return (view.getNumAnds());
	}


	/**
	 *  Gets the wordI attribute of the HTDraw object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The wordI value
	 */
	String getWordI(int i) {
		return (view.getWordI(i));
	}


	// Silvio: 29/09/2004

	/**
	 *  Description of the Method
	 *
	 * @param  search  Description of the Parameter
	 */
	void executaSearchWord(String search) {
		view.executaSearchWord(search);
	}


	// Silvio

	/**
	 *  Gets the labelCount attribute of the HTDraw object
	 *
	 * @return    The labelCount value
	 */
	String getLabelCount() {
		return view.getLabelCount();
	}


	/**
	 *  Gets the sumTags attribute of the HTDraw object
	 *
	 * @return    The sumTags value
	 */
	String getSumTags() {
		return view.getSumTags();
	}


	/**
	 *  Gets the pixelColor attribute of the HTDraw object
	 *
	 * @param  x  Description of the Parameter
	 * @param  y  Description of the Parameter
	 * @return    The pixelColor value
	 */
	Color getPixelColor(int x, int y) {
		return view.getPixelColor(x, y);
	}


	// Poligono
	/**
	 *  Gets the indicePoligono attribute of the HTDraw object
	 *
	 * @return    The indicePoligono value
	 */
	public int getIndicePoligono() {
		return model.getIndicePoligono();
	}


	/**
	 *  Gets the poligono attribute of the HTDraw object
	 *
	 * @param  indice    Description of the Parameter
	 * @param  posicaox  Description of the Parameter
	 * @param  posicaoy  Description of the Parameter
	 * @param  largura   Description of the Parameter
	 * @return           The poligono value
	 */
	public Polygon getPoligono(int indice, int posicaox, int posicaoy, int largura) {
		return view.getPoligono(indice, posicaox, posicaoy, largura);
	}


	/**
	 *  Gets the rectx attribute of the HTDraw object
	 *
	 * @param  i         Description of the Parameter
	 * @param  largura   Description of the Parameter
	 * @param  posicaox  Description of the Parameter
	 * @return           The rectx value
	 */
	public int getRectx(int i, int largura, int posicaox) {
		return view.getRectx(i, largura, posicaox);
	}


	/**
	 *  Gets the recty attribute of the HTDraw object
	 *
	 * @param  i         Description of the Parameter
	 * @param  largura   Description of the Parameter
	 * @param  posicaoy  Description of the Parameter
	 * @return           The recty value
	 */
	public int getRecty(int i, int largura, int posicaoy) {
		return view.getRecty(i, largura, posicaoy);
	}


	/**
	 *  Gets the width attribute of the HTDraw object
	 *
	 * @param  i        Description of the Parameter
	 * @param  largura  Description of the Parameter
	 * @return          The width value
	 */
	int getWidth(int i, int largura) {
		return view.getWidth(i, largura);
	}


	/**
	 *  Gets the height attribute of the HTDraw object
	 *
	 * @param  i        Description of the Parameter
	 * @param  largura  Description of the Parameter
	 * @return          The height value
	 */
	int getHeight(int i, int largura) {
		return view.getHeight(i, largura);
	}


	/**
	 *  Gets the arqAberto attribute of the HTDraw object
	 *
	 * @return    The arqAberto value
	 */
	public boolean getArqAberto() {
		return view.getArqAberto();
	}


	/**
	 *  Gets the name attribute of the HTDraw object
	 *
	 * @return    The name value
	 */
	String getName() {
		return view.getName();
	}


	/**
	 *  Description of the Method
	 *
	 * @return    Description of the Return Value
	 */
	int nGraphLines() {
		return view.nGraphLines();
	}


	/**
	 *  Gets the graphNode1 attribute of the HTDraw object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The graphNode1 value
	 */
	Point getGraphNode1(int i) {
		return view.getGraphNode1(i);
	}


	/**
	 *  Gets the graphNode2 attribute of the HTDraw object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The graphNode2 value
	 */
	Point getGraphNode2(int i) {
		return view.getGraphNode2(i);
	}


	/**
	 *  Gets the arcName attribute of the HTDraw object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The arcName value
	 */
	String getArcName(int i) {
		return view.getArcName(i);
	}


	/**
	 *  Sets the viewLineGraph attribute of the HTDraw object
	 */
	public void setViewLineGraph() {
		view.setViewLineGraph();
	}


	/**
	 *  Gets the viewLineGraph attribute of the HTDraw object
	 *
	 * @return    The viewLineGraph value
	 */
	public boolean getViewLineGraph() {
		return view.getViewLineGraph();
	}


	/**
	 *  Gets the graphColor attribute of the HTDraw object
	 *
	 * @return    The graphColor value
	 */
	String getGraphColor() {
		return view.getGraphColor();
	}


	/**
	 *  Description of the Method
	 *
	 * @param  node  Description of the Parameter
	 */
	void folderFechadoGraphLine(HTDrawNode node) {

		view.folderFechadoGraphLine(node);
	}


	/**
	 *  Description of the Method
	 *
	 * @param  i  Description of the Parameter
	 * @return    Description of the Return Value
	 */
	public boolean mostraGraph(int i) {
		return view.mostraGraph(i);
	}

	public boolean showGroup(int i) {
		return view.getShowGroup(i);
	}

	public String getGroupColor(int i) {
		return view.getGroupColor(i);
	}


       public  boolean getDirecionado(int i) {
		return view.getDirecionado(i);
	}

	public String getGraphNodeClientData(int i, int j) {
		return view.getGraphNodeClientData(i, j);
	}
	public boolean getGraphHasData(int i, int j) {
		return view.getGraphHasData(i, j);
	}
	public void setHasArc(int i, int j, boolean v) {
		view.setHasArc(i, j, v);
	}
/*
	public HTDrawNode getAdrNode(int x, int y) 
	{
		Insets insets = view.getInsets();
		sMax.x = (view.getSize().width - insets.left - insets.right) / 2;
		sMax.y = (view.getSize().height - insets.top - insets.bottom) / 2;
		sOrigin.x = sMax.x + insets.left;
		sOrigin.y = sMax.y + insets.top;		
		return(drawRoot.getAdrNode(x,y, sOrigin, sMax));	
	}
*/
}

