/*
 *  HTDrawNode.java
 *
 *  www.bouthier.net
 *  2001
 */
//package hypertree;
import java.awt.Graphics;
import java.awt.FontMetrics;
import java.util.*;
import java.awt.*;
import java.awt.image.*;
import java.awt.Color;

/**
 * The HTDrawNode class contains the drawing coordinates of a HTModelNode
 * for the HTView.
 * It implements the Composite design pattern.
 *
 * @author     silvio
 * @created    15 de Setembro de 2008
 */
class HTDrawNode {

	private HTDraw model = null;
	// drawing model
	private HTModelNode node = null;
	// encapsulated HTModelNode
	private HTCoordE ze = null;
	// current euclidian coordinates
	private HTCoordE oldZe = null;
	// old euclidian coordinates
	/**
	 *  Description of the Field
	 */
	protected HTCoordS zs = null;
	// cu rrent screen coordinates
	private HTDrawNodeComposite father = null;
	// father of this node
	
	private HTDrawNode brother = null;
	// brother of this node
	private HTNodeLabel label = null;
	// label of the node
	/**
	 *  Description of the Field
	 */
	protected boolean fastMode = false;

	// fast mode


	/*
	 *  --- Constructor ---
	 */
	/**
	 * Constructor.
	 *
	 * @param  father  the father of this node
	 * @param  node    the encapsulated HTModelNode
	 * @param  model   the drawing model
	 */
	 
	 
	 HTDrawNode isFatherClose(HTDrawNode nodeS) {
	 	 
	 	  if (nodeS == null)
	 	  	  return null; 
	 	  
	 	  if (nodeS.getHasFolder()) {
	 	  	  return nodeS;
	 	  }
	 	  else {
	 	  	  HTDrawNode S = nodeS.getFather();	 	  	  
	 	  	  if (S == null)
	 	  	  	  return null;
	 	  	  else 
	 	  	  	  return(isFatherClose(S));	 	  	  
	 	  }
	 }
	 
	 
	HTDrawNode(HTDrawNodeComposite father, HTModelNode node, HTDraw model) {
		this.father = father;
		this.node = node;
		this.model = model;

		label = new HTNodeLabel(this);

		ze = new HTCoordE(node.getCoordinates());
		oldZe = new HTCoordE(ze);
		zs = new HTCoordS();
	}


	/**
	 *  Gets the node attribute of the HTDrawNode object
	 *
	 * @return    The node value
	 */
	public HTNode getNode() {
		return node.getHTNode();
	}


	/*
	 *  --- Brother ---
	 */
	/**
	 * Sets the brother of this node.
	 *
	 * @param  brother  the borther of this node
	 */
	void setBrother(HTDrawNode brother) {
		this.brother = brother;
	}


	/**
	 * Returns the border type of the node
	 *
	 * @return    String
	 */
	String getBorderType() {
		return model.getBorderType();
	}


	/**
	 * Returns the hint color via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getHintColor() {
		return model.getHintColor();
	}


	/**
	 *  Gets the backColor attribute of the HTDrawNode object
	 *
	 * @return    The backColor value
	 */
	String getBackColor() {
		return model.getBackColor();
	}


	// 17/11/2005
	/**
	 *  Gets the backRed attribute of the HTDrawNode object
	 *
	 * @return    The backRed value
	 */
	int getBackRed() {

		return model.getBackRed();
	}


	/**
	 *  Gets the backGreen attribute of the HTDrawNode object
	 *
	 * @return    The backGreen value
	 */
	int getBackGreen() {

		return model.getBackGreen();
	}


	/**
	 *  Gets the backBlue attribute of the HTDrawNode object
	 *
	 * @return    The backBlue value
	 */
	int getBackBlue() {

		return model.getBackBlue();
	}


// ******
	/**
	 *  Gets the hasFolder attribute of the HTDrawNode object
	 *
	 * @return    The hasFolder value
	 */
	boolean getHasFolder() {
		return model.getHasFolder();
	}


	/**
	 * Returns the type of leaf node
	 *
	 * @return    type of leaf node
	 */
	String getLeafNode() {
		return model.getLeafNode();
	}


	/**
	 *  Gets the parentNode attribute of the HTDrawNode object
	 *
	 * @return    The parentNode value
	 */
	String getParentNode() {
		return model.getParentNode();
	}


	/**
	 * Returns the name of the font via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getFontNode() {
		return model.getFontNode();
	}


	/**
	 * Returns the size of the font, via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	int getFontSizeNode() {
		return model.getFontSizeNode();
	}


	/**
	 * Returns the search color via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getSearchColor() {
		return model.getSearchColor();
	}


	/**
	 * Returns the link color via model class
	 * contains thoses given in parameters.
	 *
	 * @return    String of RGB color
	 */
	String getLinkColor() {
		return model.getLinkColor();
	}


	/**
	 * Returns the text of search box, if has one.
	 *
	 * @return    String
	 */
	String getSearchWord() {
		return (model.getSearchWord());
	}


	/**
	 *  Gets the helpFile attribute of the HTDrawNode object
	 *
	 * @return    The helpFile value
	 */
	String getHelpFile() {
		return (model.getHelpFile());
	}


	/**
	 *  Gets the urlAdr attribute of the HTDrawNode object
	 *
	 * @return    The urlAdr value
	 */
	String getUrlAdr() {
		return (model.getUrlAdr());
	}


	/**
	 * Returns the children of this node in an Enumeration.
	 * If this node is a file, return a empty Enumeration.
	 * Else, return an Enumeration full with HTFileNode.
	 *
	 * @return    an Enumeration containing childs of this node
	 */
	public Enumeration childrenNode() {
		return node.childrenNode();
	}


	/*
	 *  --- Name ---
	 */
	/**
	 * Returns the name of this node.
	 *
	 * @return    the name of this node
	 */
	String getName() {
		return node.getName();
	}


	/**
	 * Returns the Arest name of this node.
	 *
	 * @return    the arest name of this node
	 */
	String getNameArest() {
		return node.getNameArest();
	}


	/**
	 * Returns the color of this node.
	 *
	 * @return    the color of this node
	 */
	String getColor() {
		return node.getColor();
	}


	/**
	 * Returns the TextColor of this node.
	 *
	 * @return    the color of this node
	 */
	String getTextColor() {
		return node.getTextColor();
	}


	/**
	 * Returns the URL of this node.
	 *
	 * @return    the URL of this node
	 */
	String getURL() {
		return node.getURL();
	}


	/**
	 * Returns the ID of this node.
	 *
	 * @return    ID  of this node
	 */
	String getID() {
		return node.getID();
	}


	/**
	 * get Highlight of the node.
	 *
	 * @return    The especialMark value
	 */
	boolean getEspecialMark() {
		return (node.getEspecialMark());
	}


	/**
	 * Returns the attributes hint of the node.
	 *
	 * @return    the hint of the node
	 */
	public String getHint() {
		return node.getHint();
	}


	/**
	 * Returns the attributes hasHint of the node.
	 *
	 * @return    boolean
	 */
	public boolean getHasHint() {
		return node.getHasHint();
	}


	/**
	 *  Gets the hasHintPai attribute of the HTDrawNode object
	 *
	 * @return    The hasHintPai value
	 */
	public boolean getHasHintPai() {
		return (node.getHasHintPai());
	}


	/**
	 *  Gets the leafNode attribute of the HTDrawNode object
	 *
	 * @return    The leafNode value
	 */
	public boolean isLeafNode() {
		return (node.isLeafNode());
	}


	/**
	 * Returns the attributes hasData of the node.
	 *
	 * @return    boolean
	 */
	public boolean getHasData() {
		return node.getHasData();
	}


	/**
	 * Set the attributes hint of the node.
	 *
	 * @param  v  The new hasHint value
	 * @void
	 */
	public void setHasHint(boolean v) {
		node.setHasHint(v);
	}


	/**
	 * Set the attributes hasData of the node.
	 *
	 * @param  v  The new hasData value
	 * @void
	 */
	public void setHasData(boolean v) {
		node.setHasData(v);
	}


	/**
	 * set true or false Highlight of the node.
	 *
	 * @param  t  The new especialMark value
	 */
	void setEspecialMark(boolean t) {
		node.setEspecialMark(t);
	}


	// 13/09/2004
	/**
	 *  Gets the nodeClientData attribute of the HTDrawNode object
	 *
	 * @return    The nodeClientData value
	 */
	String getNodeClientData() {
		return (node.getNodeClientData());
	}


	/**
	 *  Sets the nodeClientData attribute of the HTDrawNode object
	 *
	 * @param  v  The new nodeClientData value
	 */
	public void setNodeClientData(String v) {
		node.setNodeClientData(v);
	}


	// END
	/**
	 *  Gets the nameImage attribute of the HTDrawNode object
	 *
	 * @return    The nameImage value
	 */
	String getNameImage() {
		return (node.getNameImage());
	}


	/**
	 * set true or false hasArc of the node.
	 *
	 * @param  t  The new hasArc value
	 */
	void setHasArc(boolean t) {
		node.setHasArc(t);
	}


	/**
	 * get hasArc of the node.
	 *
	 * @return    The hasArc value
	 */
	boolean getHasArc() {
		return (node.getHasArc());
	}


	/**
	 * Returns the HTNodeLabel of this node.
	 *
	 * @return    HTNodeLabel of this node
	 */
	HTNodeLabel getHTNodeLabel() {
		return label;
	}


	/**
	 *  Gets the brother attribute of the HTDrawNode object
	 *
	 * @return    The brother value
	 */
	HTDrawNode getBrother() {
		return brother;
	}


	/**
	 * Returns the width of the Panel.
	 *
	 * @return    int
	 */
	int getWidthPanel() {
		return model.getWidthPanel();
	}


	/**
	 * Returns the length of this node.
	 *
	 * @return    int
	 */
	int getHeighthPanel() {
		return model.getHeightPanel();
	}


	/**
	 *  Gets the ascent attribute of the HTDrawNode object
	 *
	 * @return    The ascent value
	 */
	int getAscent() {
		return (model.getAscent());
	}


	/**
	 *  Gets the leading attribute of the HTDrawNode object
	 *
	 * @return    The leading value
	 */
	int getLeading() {
		return (model.getLeading());
	}


	/**
	 *  Gets the charWidth attribute of the HTDrawNode object
	 *
	 * @return    The charWidth value
	 */
	int getCharWidth() {
		return (model.getCharWidth());
	}


	/**
	 *  Gets the charHeight attribute of the HTDrawNode object
	 *
	 * @return    The charHeight value
	 */
	int getCharHeight() {
		return (model.getCharHeight());
	}


	/**
	 *  Gets the stringWidth attribute of the HTDrawNode object
	 *
	 * @param  nameC  Description of the Parameter
	 * @param  init   Description of the Parameter
	 * @param  end    Description of the Parameter
	 * @return        The stringWidth value
	 */
	int getStringWidth(char[] nameC, int init, int end) {
		if (nameC == null) {
			return 0;
		} else {
			return (model.getStringWidth(nameC, init, end));
		}
	}


	/**
	 *  Gets the stringWidth attribute of the HTDrawNode object
	 *
	 * @param  nameC  Description of the Parameter
	 * @return        The stringWidth value
	 */
	int getStringWidth(String nameC) {
		if (nameC == null) {
			return 0;
		} else {
			return (model.getStringWidth(nameC));
		}
	}


	/*
	 *  --- Coordinates ---
	 */
	/**
	 * Returns the current coordinates of this node.
	 * WARNING : this is NOT a copy but the true object
	 * (for performance).
	 *
	 * @return    the current coordinates
	 */
	HTCoordE getCoordinates() {
		return ze;
	}


	/**
	 *  Gets the oldCoordinates attribute of the HTDrawNode object
	 *
	 * @return    The oldCoordinates value
	 */
	HTCoordE getOldCoordinates() {
		return oldZe;
	}


	/**
	 *  Gets the screenCoordinates attribute of the HTDrawNode object
	 *
	 * @return    The screenCoordinates value
	 */
	HTCoordS getScreenCoordinates() {
		return zs;
	}


	/**
	 *  Gets the screenCoordinatesFather attribute of the HTDrawNode object
	 *
	 * @return    The screenCoordinatesFather value
	 */
	HTCoordS getScreenCoordinatesFather() {
		if (father == null) {
			return null;
		} else {
			return (father.getScreenCoordinates());
		}
	}


	/**
	 * Refresh the screen coordinates of this node.
	 *
	 * @param  sOrigin  the origin of the screen plane
	 * @param  sMax     the (xMax, yMax) point in the screen plane
	 */
	void refreshScreenCoordinates(HTCoordS sOrigin, HTCoordS sMax) {
		zs.projectionEtoS(ze, sOrigin, sMax);
	}


	/*
	 *  --- Drawing ---
	 */
	/**
	 * Draws the branches from this node to
	 * its children.
	 * Overidden by HTDrawNodeComposite
	 *
	 * @param  g  the graphic context
	 */
	void drawBranches(Graphics g) {
	}


	/**
	 * Draws this node.
	 *
	 * @param  g              the graphic context
	 * @param  MostrarFigura  Description of the Parameter
	 */
	void drawNodes(Graphics g, boolean MostrarFigura) {
		//if (fastMode == false) {
		label.draw(g, fastMode, MostrarFigura);
		//}
	}


	// 12/09/2008
	/**
	 *  Description of the Method
	 *
	 * @param  g  Description of the Parameter
	 */
	void drawLinesGraph(Graphics g) {
		label.drawLinesGraph(g, fastMode);
	}


	/**
	 *  Description of the Method
	 *
	 * @param  g              Description of the Parameter
	 * @param  MostrarFigura  Description of the Parameter
	 */
	void drawNodes0(Graphics g, boolean MostrarFigura) {
		//if (fastMode == false) {
		label.draw0(g, fastMode, MostrarFigura);
		//}
	}


	/**
	 * Draws hint of the node.
	 *
	 * @param  g  the graphic context
	 */
	void drawHint(Graphics g) {
		//if (fastMode == false) {
		label.drawHint(g);
		//}
	}


	/**
	 * Returns the minimal distance between this node
	 * and his father and his brother.
	 *
	 * @return    the minimal distance
	 */
	int getSpace() {
		int dF = -1;
		int dB = -1;
		int dxP = -1;
		int dyB = -1;
		boolean emColuna = false;
		HTCoordS zF = null;
		HTCoordS zB = null;

		if (father != null) {
			zF = father.getScreenCoordinates();
			dF = zs.getDistance(zF);
			dxP = zs.getDistanceX(zF);
		}
		if (brother != null) {
			zB = brother.getScreenCoordinates();
			dB = zs.getDistance(zB);
			dyB = zs.getDistanceY(zB);
		}

		if ((dF == -1) && (dB == -1)) {
			return -1;
		} else if (dF == -1) {
			return dB;
		} else if (dB == -1) {
			return dF;
		} else {
			int min = Math.min(dF, dB);

			if (min <= model.getCharHeight() + 1) {
				return min;
			} else {
				if ((dxP > dyB) && (dyB > model.getCharHeight() + 1)) {
					if ((Math.abs(zs.x - zF.x) < dF / 2) || ((Math.abs(zs.x - zB.x) < dF) &&
							(Math.abs(zs.y - zB.y) < model.getCharHeight()))) {
						return min;
					} else if (isLeafNode()) {
						return ((dF + dB) / 2);
					} else {
						return (dF);
					}
				} else {
					return min;
				}
			}
		}

	}


	/*
	 *  --- Translation ---
	 */
	/**
	 * Translates this node by the given vector.
	 *
	 * @param  t  the translation vector
	 */
	void translate(HTCoordE t) {
		ze.translate(oldZe, t);
	}


	/**
	 * Transform this node by the given transformation.
	 *
	 * @param  t  the transformation
	 */
	void transform(HTTransformation t) {
		ze.copy(oldZe);
		ze.transform(t);
	}


	/**
	 * Ends the translation.
	 */
	void endTranslation() {
		oldZe.copy(ze);
	}


	/**
	 * Restores the hyperbolic tree to its origin.
	 */
	void restore() {
		HTCoordE orig = node.getCoordinates();
		ze.x = orig.x;
		ze.y = orig.y;
		oldZe.copy(ze);
	}


	/**
	 * Sets the fast mode, where nodes are no more drawed.
	 *
	 * @param  mode  setting on or off.
	 */
	void fastMode(boolean mode) {
		if (mode != fastMode) {
			fastMode = mode;
		}
	}


	/*
	 *  --- Node searching ---
	 */
	/**
	 * Returns the node (if any) whose screen coordinates' zone
	 * contains thoses given in parameters.
	 *
	 * @param  zs  the given screen coordinate
	 * @return     the searched HTDrawNode if found;
	 *              <CODE>null</CODE> otherwise
	 */
	HTDrawNode findNode(HTCoordS zs) {
		if (label.contains(zs)) {
			return this;
		} else {
			return null;
		}
	}


	/**
	 *  Gets the clickOnImage attribute of the HTDrawNode object
	 *
	 * @return    The clickOnImage value
	 */
	boolean getClickOnImage() {
		return label.getClickOnImage();
	}


	/**
	 *  Description of the Method
	 *
	 * @param  idNode  Description of the Parameter
	 * @return         Description of the Return Value
	 */
	HTDrawNode findNode(String idNode) {
		if (getID().equals(idNode)) {
			setEspecialMark(true);
			return this;
		} else {
			return null;
		}
	}


	// 13/09/2004
	/**
	 *  Description of the Method
	 *
	 * @param  zs  Description of the Parameter
	 * @return     Description of the Return Value
	 */
	int verifyFolder(HTCoordS zs) {
		return (label.verifyFolder(zs));
	}


	// END
	/*
	 *  --- ToString ---
	 */
	/**
	 * Returns a string representation of the object.
	 *
	 * @return    a String representation of the object
	 */
	public String toString() {
		String result = getName() +
				"\n\t" + ze +
				"\n\t" + zs;
		return result;
	}


	/**
	 *  Gets the numAnds attribute of the HTDrawNode object
	 *
	 * @return    The numAnds value
	 */
	int getNumAnds() {
		return (model.getNumAnds());
	}


	/**
	 *  Gets the wordI attribute of the HTDrawNode object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The wordI value
	 */
	String getWordI(int i) {
		return (model.getWordI(i));
	}


	// 14/11/2005
	/**
	 * get the representation type of search:
	 *   line: line thicher
	 *   blende: blende mode. This type use transparency color.
	 *
	 * @return    The searchType value
	 */
	boolean getSearchType() {
		return model.getSearchType();
	}


	/**
	 * Indicates if the hypertree space is in search mode.
	 *
	 * @return    The isSearch value
	 */
	boolean getIsSearch() {
		return model.getIsSearch();
	}


	// *************
	/**
	 *  Gets the labelCount attribute of the HTDrawNode object
	 *
	 * @return    The labelCount value
	 */
	String getLabelCount() {
		return model.getLabelCount();
	}


	/**
	 *  Gets the sumTags attribute of the HTDrawNode object
	 *
	 * @return    The sumTags value
	 */
	String getSumTags() {
		return model.getSumTags();
	}


	/**
	 *  Gets the image attribute of the HTDrawNode object
	 *
	 * @return    The image value
	 */
	public BufferedImage getImage() {
		return (node.getImage());
	}


	/**
	 *  Gets the pixelColor attribute of the HTDrawNode object
	 *
	 * @param  x  Description of the Parameter
	 * @param  y  Description of the Parameter
	 * @return    The pixelColor value
	 */
	Color getPixelColor(int x, int y) {
		return model.getPixelColor(x, y);
	}


	//Bruno

	/**
	 *  Sets the nodeClientStatus attribute of the HTDrawNode object
	 *
	 * @param  valor  The new nodeClientStatus value
	 */
	void setNodeClientStatus(String valor) {
		node.setNodeClientStatus(valor);
	}


	//Poligono
	/**
	 *  Gets the indicePoligono attribute of the HTDrawNode object
	 *
	 * @return    The indicePoligono value
	 */
	public int getIndicePoligono() {
		return node.getIndicePoligono();
	}


	/**
	 *  Gets the poligono attribute of the HTDrawNode object
	 *
	 * @param  indice    Description of the Parameter
	 * @param  posicaox  Description of the Parameter
	 * @param  posicaoy  Description of the Parameter
	 * @param  largura   Description of the Parameter
	 * @return           The poligono value
	 */
	public Polygon getPoligono(int indice, int posicaox, int posicaoy, int largura) {
		return model.getPoligono(indice, posicaox, posicaoy, largura);
	}


	/**
	 *  Gets the rectx attribute of the HTDrawNode object
	 *
	 * @param  i         Description of the Parameter
	 * @param  largura   Description of the Parameter
	 * @param  posicaox  Description of the Parameter
	 * @return           The rectx value
	 */
	public int getRectx(int i, int largura, int posicaox) {
		return model.getRectx(i, largura, posicaox);
	}


	/**
	 *  Gets the recty attribute of the HTDrawNode object
	 *
	 * @param  i         Description of the Parameter
	 * @param  largura   Description of the Parameter
	 * @param  posicaoy  Description of the Parameter
	 * @return           The recty value
	 */
	public int getRecty(int i, int largura, int posicaoy) {
		return model.getRecty(i, largura, posicaoy);
	}


	/**
	 *  Gets the width attribute of the HTDrawNode object
	 *
	 * @param  i        Description of the Parameter
	 * @param  largura  Description of the Parameter
	 * @return          The width value
	 */
	public int getWidth(int i, int largura) {
		return model.getWidth(i, largura);
	}


	/**
	 *  Gets the height attribute of the HTDrawNode object
	 *
	 * @param  i        Description of the Parameter
	 * @param  largura  Description of the Parameter
	 * @return          The height value
	 */
	public int getHeight(int i, int largura) {
		return model.getHeight(i, largura);
	}


	/**
	 *  Gets the arqAberto attribute of the HTDrawNode object
	 *
	 * @return    The arqAberto value
	 */
	public boolean getArqAberto() {
		return model.getArqAberto();
	}


	/**
	 *  Gets the father attribute of the HTDrawNode object
	 *
	 * @return    The father value
	 */
	HTDrawNode getFather() {
		return father;
	}


	/**
	 *  Description of the Method
	 *
	 * @return    Description of the Return Value
	 */
	int nGraphLines() {
		return model.nGraphLines();
	}


	/**
	 *  Gets the graphNode1 attribute of the HTDrawNode object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The graphNode1 value
	 */
	Point getGraphNode1(int i) {
		return model.getGraphNode1(i);
	}


	/**
	 *  Gets the graphNode2 attribute of the HTDrawNode object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The graphNode2 value
	 */
	Point getGraphNode2(int i) {
		return model.getGraphNode2(i);
	}


	/**
	 *  Description of the Method
	 *
	 * @param  x0  Description of the Parameter
	 * @param  Y0  Description of the Parameter
	 */
	public void saveXY(int x0, int Y0) {
		node.saveXY(x0, Y0);
	}


	/**
	 *  Gets the savedX attribute of the HTDrawNode object
	 *
	 * @return    The savedX value
	 */
	public int getSavedX() {
		return node.getSavedX();
	}


	/**
	 *  Gets the savedY attribute of the HTDrawNode object
	 *
	 * @return    The savedY value
	 */
	public int getSavedY() {
		return node.getSavedY();
	}


	/**
	 *  Gets the graphColor attribute of the HTDrawNode object
	 *
	 * @return    The graphColor value
	 */
	String getGraphColor() {
		return model.getGraphColor();
	}


	/**
	 *  Gets the viewLineGraph attribute of the HTDrawNode object
	 *
	 * @return    The viewLineGraph value
	 */
	public boolean getViewLineGraph() {
		return model.getViewLineGraph();
	}


	/**
	 *  Gets the arcName attribute of the HTDrawNode object
	 *
	 * @param  i  Description of the Parameter
	 * @return    The arcName value
	 */
	public String getArcName(int i) {
		return model.getArcName(i);
	}


	/**
	 *  Description of the Method
	 *
	 * @param  i  Description of the Parameter
	 * @return    Description of the Return Value
	 */
	public boolean mostraGraph(int i) {
		return model.mostraGraph(i);
	}

	public boolean showGroup(int i) {
		return model.showGroup(i);
	}

	public String getGroupColor(int i) {
		return model.getGroupColor(i);
	}


       public  boolean getDirecionado(int i) {
		return model.getDirecionado(i);
	}

	public String getGraphNodeClientData(int i, int j) {
		return model.getGraphNodeClientData(i, j);
	}

	public boolean getGraphHasData(int i, int j) {
		return model.getGraphHasData(i, j);
	}
	public void setHasArc(int i, int j, boolean v) {
		model.setHasArc(i, j, v);
	}
	
	
	/*
	public HTDrawNode getAdrNode(int x, int y) 
	{		
		if (brother != null) {
			System.out.println("No  Nulo");
		}
		if (father != null) {
			System.out.println("No  Nulo father");
		}		
		return(null);	
	}

	*/

}

